@@ -63,6 +63,7 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Usar Gravatar e favicon avatars",
     "Register as application for mail links" : "Registar como aplicação para ligações de correio",
     "Register" : "Registar",
+    "Shared with me" : "Partilhadas comigo",
     "Trusted senders" : "Remetentes confiáveis",
     "About" : "Sobre",
     "Keyboard shortcuts" : "Atalhos de teclado",
@@ -72,6 +73,7 @@ OC.L10N.register(
     "Search" : "Pesquisar",
     "Send" : "Enviar",
     "Refresh" : "Atualizar",
+    "Ok" : "CONFIRMAR",
     "From" : "De",
     "Select account" : "Selecionar uma conta",
     "To" : "Para",
@@ -117,6 +119,10 @@ OC.L10N.register(
     "domain" : "domínio",
     "Remove" : "Remover",
     "email" : "email",
+    "Last hour" : "Ultima hora",
+    "Today" : "Hoje",
+    "Last week" : "Ultima semana",
+    "Last month" : "Ultimo mês",
     "Choose target folder" : "Escolher pasta de destino",
     "Important info" : "Informação importante",
     "Other" : "Outro",
@@ -210,6 +216,9 @@ OC.L10N.register(
     "Valid until" : "Válido até",
     "Certificate" : "Certificado",
     "Submit" : "Submeter",
+    "Group" : "Grupo",
+    "Shared" : "Partilhados",
+    "Shares" : "Partilhas",
     "Account connected" : "Conta ligada",
     "Connect your mail account" : "Ligue a sua conta de e-mail",
     "All" : "Todos",
