@@ -93,6 +93,7 @@ OC.L10N.register(
     "Search" : "Sök",
     "Send" : "Skicka",
     "Refresh" : "Uppdatera",
+    "Ok" : "Ok",
     "Send later" : "Skicka senare",
     "Message {id} could not be found" : "Meddelandet {id} hittades inte",
     "From" : "Från",
@@ -186,6 +187,9 @@ OC.L10N.register(
     "Remove" : "Ta bort",
     "email" : "e-post",
     "Itinerary for {type} is not supported yet" : "Resplan för {type} stöds inte än",
+    "Last hour" : "Senaste timmen",
+    "Today" : "Idag",
+    "Yesterday" : "I går",
     "Loading messages …" : "Läser in meddelanden …",
     "Choose target folder" : "Välj målmapp",
     "No more submailboxes in here" : "Inga fler undermappar här",
@@ -348,6 +352,10 @@ OC.L10N.register(
     "Delete certificate" : "Ta bort certifikat",
     "Certificate" : "Certifikat",
     "Submit" : "Skicka",
+    "Group" : "Grupp",
+    "Shared" : "Delad",
+    "Shares" : "Delningar",
+    "Insert" : "Infoga",
     "Account connected" : "Konto anslutet",
     "Connect your mail account" : "Anslut ditt e-postkonto",
     "All" : "Alla",
